@@ -14,4 +14,4 @@ class TestTools(unittest.TestCase):
         url2ip('www.python-office.com')
 
     def test_image_watermark(self):
-        add_watermark(file=r'D:\work\BaiduNetdiskWorkspace\personal\linux\workplace\docs\we-media\自媒体素材\图片\python-office\目录结构\目录结构.jpg',mark='程序员晚枫')
+        add_watermark(file=r'.\目录结构.jpg',mark='程序员晚枫')
